@@ -32,12 +32,22 @@ class LatexTable:
     def __init__(self, data, headers=None, smart_latex=True,
                  escape_under_score=True, alignment=None, rotate_header=False,
                  latex_map=None):
-        if headers is not None:
-            assert (len(headers) == len(data[0]))
+        # Make sure #data columns matches #header columns, using any non-zero
+        # length if data or headers are missing
+        if len(data) > 0:
+            num_col = len(data[0])
+            if headers:
+                assert num_col == len(headers)
+        else:
+            if headers is not None:
+                num_col = len(headers)
+            else:
+                # LaTeX requires at least one column
+                num_col = 1
 
         self.headers = headers
         self.data = data
-        self.num_col = len(data[0])
+        self.num_col = num_col
         self.smart_latex = smart_latex
         self.escape_under_score = escape_under_score
         self.alignment = self._auto_align() if alignment is None else alignment
@@ -48,9 +58,6 @@ class LatexTable:
     def _auto_align(self):
         return '|' + 'c|' * self.num_col
 
-    def _xcolor_from_tuple(self, c):
-        return '[RGB]{%d,%d,%d}' % (c[0], c[1], c[2])
-
     def _format(self, s):
         if s in self.latex_map:
             return self.latex_map[s]
@@ -124,8 +131,8 @@ class LatexTable:
         # decorate it
 
         for (i, j), c in self.cell_color.items():
-            tdata[i][j] = '\\cellcolor' + self._xcolor_from_tuple(c) + \
-                          ' ' + tdata[i][j]
+            xcolor = '[RGB]{%d,%d,%d}' % (c[0], c[1], c[2])
+            tdata[i][j] = '\\cellcolor' + xcolor + ' ' + tdata[i][j]
 
         for line in tdata:
             ret += ' & '.join(line) + '\\\\\n'
@@ -163,22 +170,21 @@ class LatexFactory:
     def build_param_table(cls, mps, merr=None, float_format='%5.3e',
                           smart_latex=True, latex_map=None):
         """build latex parameter table"""
-        headers = ['', 'Name', 'Value', 'Para Error', 'Error+',
-                   'Error-', 'Limit+', 'Limit-', 'FIXED', ]
+        headers = ['', 'Name', 'Value', 'Hesse Error', 'Minos Error-',
+                   'Minos Error+', 'Limit-', 'Limit+', 'Fixed?', ]
 
         data = []
         for i, mp in enumerate(mps):
             minos_p, minos_m = ('', '') if merr is None or mp.name not in merr else \
-                (merr[mp.name].upper, merr[mp.name].lower)
-            limit_p, limit_m = ('', '') if not mp.has_limits else \
-                (mp.upper_limit, mp.lower_limit)
-            fixed = 'FIXED' if mp.is_fixed else ''
-            j = i + 1
+                ('%g' % merr[mp.name].upper, '%g' % merr[mp.name].lower)
+            limit_p = '' if mp.upper_limit is None else '%g' % mp.upper_limit
+            limit_m = '' if mp.lower_limit is None else '%s' % mp.lower_limit
+            fixed = 'Yes' if mp.is_fixed else 'No'
             tmp = [
-                j,
+                i,
                 mp.name,
-                mp.value,
-                mp.error,
+                '%g' % mp.value,
+                '%g' % mp.error,
                 minos_m,
                 minos_p,
                 limit_m,
